/* eslint-disable prefer-destructuring */
import React, { Component } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Button, message } from 'antd';
import { StandardTableList } from '../../components/AXList';
import Ellipsis from '../../components/Ellipsis';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { addRowKey } from '../../utils/utils';

const Message = message;

@connect(({ loading, campus, merchant }) => ({
  campus,
  merchant,
  fetching: loading.models.merchant,
  loading: loading.models.campus,
}))
export default class CampusListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentDidMount() {
    const { merchants } = this.state;
    let merchantId;
    if (merchants && merchants.length) {
      merchantId = merchants[0].split('||')[1];
    }
    this.props.dispatch({
      type: 'campus/fetchCampusList',
      payload: { merchantId, ...this.state.Queryers },
    });
  }
  handleCreateOperation = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/campus/create',
      state: this.state,
    }));
  };
  handleEditOperation = (item) => {
    this.props.dispatch(routerRedux.push({
      pathname: `/campus/edit/${item.id}`,
      state: this.state,
    }));
  };
  handleFilterOperation = (params, states) => {
    const { merchants } = this.state;
    let merchantId;
    if (merchants && merchants.length) {
      merchantId = merchants[0].split('||')[1];
    }
    this.props.dispatch({
      type: 'campus/fetchCampusList',
      payload: { merchantId, ...params },
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  };
  handleModalFilterOperation = () => {
    const { getFieldValue } = this.props.form;
    const merchants = getFieldValue('merchants');
    let merchantId;
    if (merchants && merchants.length) {
      merchantId = merchants[0].split('||')[1];
    }
    this.props.dispatch({
      type: 'campus/fetchCampusList',
      payload: {
        merchantId,
        ...this.state.Queryers,
      },
    });
    this.setState({ merchants });
    this.handleFilterModalDestroy();
  };
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };
  handleRemoteSelectSearch = (value) => {
    this.props.dispatch({
      type: 'merchant/fetchMerchantList',
      payload: {
        pageSize: 50,
        name: value,
      },
    });
  };

  render() {
    const { loading, campus } = this.props;
    const { list, totalSize, pageSize, pageNo } = campus;
    const renderOperation = (item) => {
      return (
        <div>
          <Button
            size="small"
            type="primary"
            onClick={() => this.handleEditOperation(item)}
          >编辑
          </Button>
        </div>
      );
    };
    const batchActions = [{
      key: 'edit',
      name: '批量编辑',
    }];
    const basicSearch = {
      keys: [{
        name: '校区编号',
        field: 'code',
      }, {
        name: '校区名称',
        field: 'name',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '校区编号',
      key: 1,
      dataIndex: 'code',
      width: '15%',
    }, {
      title: '校区名称',
      key: 2,
      dataIndex: 'name',
      width: '30%',
      render: text => (
        <Ellipsis tooltip lines={1}>{text}</Ellipsis>
      ),
    }, {
      title: '校区联系人',
      key: 3,
      dataIndex: 'contactName',
      width: '20%',
    }, {
      title: '联系电话',
      key: 4,
      dataIndex: 'mobile',
      width: '12%',
    }, {
      title: '更新时间',
      key: 5,
      dataIndex: 'gmtModified',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '15%',
    }, {
      title: '操作',
      key: 6,
      dataIndex: 'operation',
      render: (_, record) => renderOperation(record),
      width: '6%',
      align: 'right',
    }];
    return (
      <PageHeaderLayout>
        <Card>
          <StandardTableList
            columns={columns}
            loading={loading}
            dataSource={addRowKey(list)}
            header={{
              basicSearch,
              onFilterClick: this.handleFilterOperation,
              onCreateClick: this.handleCreateOperation,
            }}
            footer={{
              pagination,
              batchActions,
              onBatchClick: this.handleBatchOperation,
            }}
            keepUIState={{ ...this.state.UIParams }}
            showStatusSelect={false}
          />
        </Card>
      </PageHeaderLayout>
    );
  }
}
